@@ -3,9 +3,28 @@
 
 ## }
 
+##' return 'x' unless it is NULL where you'd use 'orElse'
+`%||%` <- function(x, orElse) if(!is.null(x)) x else orElse
+
+
 ## if(!exists("rep_len", mode = "function")) # old R version
 ##     rep_len <- function(x, length.out) rep(x, length.out=length.out)
 
+if(getRversion() < "4.0.0") {
+  deparse1 <- function (expr, collapse = " ", width.cutoff = 500L, ...)
+      paste(deparse(expr, width.cutoff, ...), collapse = collapse)
+
+if(getRversion() < "3.5") {
+## if(!is.function(.BaseNamespaceEnv$...length)) # ...length() only in R >= 3.5.0
+    ## This substitute is kludgy  by using parent.env() -- but it works (sometimes)
+    ## in funEnv() -- see ../R/misc-goodies.R
+    ...length <- function() eval(quote(length(list(...))), envir = parent.frame())
+
+    isTRUE  <- function(x) is.logical(x) && length(x) == 1L && !is.na(x) && x
+    isFALSE <- function(x) is.logical(x) && length(x) == 1L && !is.na(x) && !x
+}
+
+}## Rv < 4.0.0
 
 .set.eps_view <- function() {
     ## This assumes  "gv"  in your path --- ideally this would be configured!
